#
# spec file for package python-unidiff
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-unidiff
Version:        0.7.5
Release:        1.5
Summary:        Unified diff parsing/metadata extraction library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/matiasb/python-unidiff
Source:         https://github.com/matiasb/python-unidiff/archive/v%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Python library to parse and interact with unified diff data.

%prep
%setup -q -n python-unidiff-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/unidiff
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative unidiff

%postun
%python_uninstall_alternative unidiff

%files %{python_files}
%doc HISTORY README.rst
%license LICENSE
%python_alternative %{_bindir}/unidiff
%{python_sitelib}/unidiff
%{python_sitelib}/unidiff-%{version}.dist-info

%changelog
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.5:
  * Fixed issue with spaces in filename when using custom git
    prefix.
  * Support binary patch format.
* Mon Jun 27 2022 Martin Liška <mliska@suse.cz>
- Update to version 0.7.4
  * Fixed git diff parsing issues (filename with spaces,
    only one added/deleted file).
* Wed Feb  9 2022 Martin Liška <mliska@suse.cz>
- Update to version 0.7.3
  * Fixed RE_BINARY_DIFF regex to make it a raw string.
* Fri Jan 28 2022 Martin Liška <mliska@suse.cz>
- Update to version 0.7.2
  * Fixed issue when parsing git diff header generated with --no-prefix.
- Update to version 0.7.1
  * Improved git added/deleted file detection.
  * Added newline optional param when parsing from_filename.
* Sun Aug 15 2021 Martin Liška <mliska@suse.cz>
- Update to version 0.7.0
  * Fixed issues handling multiple git renames.
  * Renamed files return target filename as PatchedFile.path.
  * Fixed error when first change is a binary file.
  * Added source code type hints.
* Wed May 27 2020 Martin Liška <mliska@suse.cz>
- Update to version 0.6.0
  * Updated PatchSet constructor to accept an optional (default to False)
    metadata_only parameter to only keep diff metadata information without
    the diff text data (better performance).
  * Identify and track changed binary files.
  * Added support for git rename syntax.
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Jun  3 2019 pgajdos@suse.com
- run the testsuite, call spec-cleaner
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
* Tue May 29 2018 toddrme2178@gmail.com
- Update to version 0.5.5
  * Updated PatchSet constructor to accept string data.
  * Added support to parse extended patch info.
* Tue Nov  7 2017 toddrme2178@gmail.com
- initial version
